﻿//=================================================================
//
//                    Rarekiller - Plugin
//                      Autor: katzerle
//          Honorbuddy Plugin - www.thebuddyforum.com
//
//==================================================================
using System;
using System.IO;
using System.Xml;
using System.Windows.Media;

using Styx;
using Styx.Common;
using Styx.CommonBot;
using Styx.WoWInternals.WoWObjects;


namespace katzerle
{

    // -------------- Settings -------------------
    class RarekillerSettings
    {
        public RarekillerSettings()
        {
            if (StyxWoW.Me != null)
                try
                {
                    Load();
                }
                catch (Exception e)
                {
                    Logging.WriteDiagnostic(Colors.Red, e.Message);
                }
        }

        // Rarekiller
        public bool HUNTbyID = false;
        public string MobID = "";
        public bool KillTagged = false;
        // Pull spell
        public bool DefaultPull = true;
        public string Pull = "";
        public bool ForceRange = false;
        public string Range = "";
        // Special Rares
        public bool Camel = false;
        public bool Aeonaxx = false;
        public bool Voidtalon = false;
        // Tamer
        public bool Hunteractivated = true;
        public bool NotKillTameable = false;        
        public bool TameByID = false;
        public string TameMobID = "";
        // Configurable XML
        public bool KillList = true;
        public bool ObjectsCollector = true;
        public bool InteractNPC = true;
        public bool TameList = false;     
        // General Settings
        public string BlacklistTime = "180";
        public string BlacklistEnd = "300";
        public bool Keyer = true;     
        // Alerts      
        public bool Alert = true;
        public bool Wisper = true;
        public bool BNWisper = true;
        public bool Guild = false;        
        public string SoundfileWisper = Rarekiller.Soundfile2;
        public string SoundfileGuild = Rarekiller.Soundfile2;
        public string SoundfileFoundRare = Rarekiller.Soundfile;
        public bool LUAoutput = false;
        // Some other Stuff
        public BlacklistFlags Flags = BlacklistFlags.All;
        public Int32 PullCounter = 0;
        public Int32 MaxPullCounter = 3;
        public ulong GuidCurrentPull = 0;
        public Int64 BlacklistCounter = 0;
        public Int32 Tamedistance = 12; 

        /// <summary>
        /// Loads the Configfile
        /// </summary>
        public void Load()
        {
            //    XmlTextReader reader;
            XmlDocument xml = new XmlDocument();
            XmlNode xvar;
            
            string sPath = Rarekiller.SettingsPath;

            if (!Directory.Exists(sPath))
            {
                Logging.WriteDiagnostic(Colors.MediumPurple, "Rarekiller: Creating Settings directory");
                Directory.CreateDirectory(sPath);
            }

            sPath = Path.Combine(sPath, StyxWoW.Me.RealmName, StyxWoW.Me.Name, "Rarekiller.config");

            Logging.WriteDiagnostic(Colors.MediumPurple, "Rarekiller: Loading config file");
            if (!File.Exists(sPath))
            {
                Logging.WriteDiagnostic(Colors.MediumPurple, "Rarekiller: No Special Config - Continuing with Default Config Values");
                return;
            }
            System.IO.FileStream fs = new System.IO.FileStream(@sPath, System.IO.FileMode.OpenOrCreate, System.IO.FileAccess.ReadWrite);
            try
            {
                xml.Load(fs);
                fs.Close();
            }
            catch (Exception e)
            {
                Logging.WriteDiagnostic(Colors.Red, e.Message);
                fs.Close();
                return;
            }

            try
            {
                if (xml == null)
                    return;

                // Load Variables - Rarekiller
                xvar = xml.SelectSingleNode("//Rarekiller/HuntByID");
                if (xvar != null)
                {
                    HUNTbyID = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + HUNTbyID.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/MobID");
                if (xvar != null)
                {
                    MobID = Convert.ToString(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + MobID.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/KillTagged");
                if (xvar != null)
                {
                    KillTagged = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + KillTagged.ToString());
                }

                // Load Variables - Pullspell
                xvar = xml.SelectSingleNode("//Rarekiller/DefaultPull");
                if (xvar != null)
                {
                    DefaultPull = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + DefaultPull.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/Pull");
                if (xvar != null)
                {
                    Pull = Convert.ToString(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Pull.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/ForceRange");
                if (xvar != null)
                {
                    ForceRange = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + ForceRange.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/Range");
                if (xvar != null)
                {
                    Range = Convert.ToString(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Range.ToString());
                }

                // Load Variables - Special Rares
                xvar = xml.SelectSingleNode("//Rarekiller/Camel");
                if (xvar != null)
                {
                    Camel = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Camel.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/Aeonaxx");
                if (xvar != null)
                {
                    Aeonaxx = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Aeonaxx.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/Voidtalon");
                if (xvar != null)
                {
                    Voidtalon = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Voidtalon.ToString());
                }

                // Load Variables - Tamer
                xvar = xml.SelectSingleNode("//Rarekiller/NotKillTameable");
                if (xvar != null)
                {
                    NotKillTameable = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + NotKillTameable.ToString());
                }               

                xvar = xml.SelectSingleNode("//Rarekiller/TameByID");
                if (xvar != null)
                {
                    TameByID = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + TameByID.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/TameMobID");
                if (xvar != null)
                {
                    TameMobID = Convert.ToString(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + TameMobID.ToString());
                }      

                // Load Variables - Configurable XMLs
                xvar = xml.SelectSingleNode("//Rarekiller/KillList");
                if (xvar != null)
                {
                    KillList = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + KillList.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/InteractNPC");
                if (xvar != null)
                {
                    InteractNPC = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + InteractNPC.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/ObjectsCollector");
                if (xvar != null)
                {
                    ObjectsCollector = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + ObjectsCollector.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/TameList");
                if (xvar != null)
                {
                    TameList = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + TameList.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/Keyer");
                if (xvar != null)
                {
                    Keyer = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Keyer.ToString());
                }                                         

                xvar = xml.SelectSingleNode("//Rarekiller/BlacklistTime");
                if (xvar != null)
                {
                    BlacklistTime = Convert.ToString(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + BlacklistTime.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/BlacklistEnd");
                if (xvar != null)
                {
                    BlacklistEnd = Convert.ToString(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + BlacklistEnd.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/LUAoutput");
                if (xvar != null)
                {
                    LUAoutput = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + LUAoutput.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/Alert");
                if (xvar != null)
                {
                    Alert = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Alert.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/Wisper");
                if (xvar != null)
                {
                    Wisper = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Wisper.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/BNWisper");
                if (xvar != null)
                {
                    BNWisper = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + BNWisper.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/GuildChat");
                if (xvar != null)
                {
                    Guild = Convert.ToBoolean(xvar.InnerText);
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + Guild.ToString());
                }
                
                xvar = xml.SelectSingleNode("//Rarekiller/SoundfileFoundRare");
                if (xvar != null)
                {
                    if (Convert.ToString(xvar.InnerText) != "")
                        SoundfileFoundRare = Convert.ToString(xvar.InnerText);
                    else
                        SoundfileFoundRare = Rarekiller.Soundfile;
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + SoundfileFoundRare.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/SoundfileWisper");
                if (xvar != null)
                {
                    if (Convert.ToString(xvar.InnerText) != "")
                        SoundfileWisper = Convert.ToString(xvar.InnerText);
                    else
                        SoundfileWisper = Rarekiller.Soundfile;
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + SoundfileWisper.ToString());
                }

                xvar = xml.SelectSingleNode("//Rarekiller/SoundfileGuild");
                if (xvar != null)
                {
                    if (Convert.ToString(xvar.InnerText) != "")
                        SoundfileGuild = Convert.ToString(xvar.InnerText);
                    else
                        SoundfileGuild = Rarekiller.Soundfile;
                    Logging.WriteDiagnostic("Rarekiller Load: " + xvar.Name + "=" + SoundfileGuild.ToString());
                }                                        
            }
            catch (Exception e)
            {
                Logging.WriteDiagnostic(Colors.Red, e.Message);
            }
        }
    }
}
